# SimpleCovidAPI
A client library for the SimpleCovidAPI that retrieves COVID-19 data.

### Installation

    pip3 install SimpleCovidAPI  # for python 3
    pip install SimpleCovidAPI  # for python 2

### Usage

    from SimpleCovidAPI import sca
    
    print('Cases: ' + sca.cases())
    print('Deaths: ' + sca.deaths())
    print('Recoveries: ' + sca.recoveries())

### Docs
Full documentation availabe <a href="https://gadhagod.github.io/SimpleCovidAPI">here</a>.
